//
//  CurrentRecordColumnDefinition.m
//  CustomSparklineColumn
//
//  Created by Darrell Kress on 2/26/14.
//  Copyright (c) 2014 Darrell Kress. All rights reserved.
//

#import "CurrentRecordColumnDefinition.h"
#import "TeamSeasonData.h"

@implementation CurrentRecordColumnDefinition
// in this case we want to format the data going into the underlying textLabel and assign it to the textLabel.attributedText.
-(IGGridViewCell *)gridView:(IGGridView *)gridView createCell:(IGCellPath *)path usingDataSource:(IGGridViewDataSourceHelper *)dataSource
{
    // first we see if we can grab a cell from the recycler
    IGGridViewCell* cell = (IGGridViewCell*)[gridView dequeueReusableCellWithIdentifier:@"CurrentRecordCell"];
    if (!cell)
    {
        // nope, make a new one
        cell = [[IGGridViewCell alloc]initWithReuseIdentifier:@"CurrentRecordCell"];
    }
    
    // get the data object that is going to be associated with the row, and send it to a method to generate the text we want to display.
    TeamSeasonData* data = [dataSource resolveDataObjectForRow:path];
    
    // set the textLabel.attributedText.  Since we aren't making a custom cell we are using default IGGridVeiwCell object and just modifing what is being shown.
    cell.textLabel.attributedText = [self generateText: data];

    return cell;
}


-(NSAttributedString*)generateText:(TeamSeasonData*)data
{
    NSInteger wins = 0;
    NSInteger losses = 0;
    NSInteger ties = 0;
    
    if (data!=nil)
    {
        for (int i = 0; i < data.recordData.count  ;i ++)
        {
            NSNumber* value = (NSNumber*) data.recordData[i];
            
            if (value.integerValue==0)
                ties++;
            else if (value.integerValue>0)
                wins++;
            else
                losses++;
        }
        
    }
    
    NSMutableAttributedString* attrString = [[NSMutableAttributedString alloc]init];
    
    NSMutableAttributedString* winString = [[NSMutableAttributedString alloc]initWithString:[NSString stringWithFormat:@"%d",wins]];
    NSRange winRange;
    winRange.length = winString.length;
    winRange.location = 0;
    [winString addAttribute:NSForegroundColorAttributeName value:[UIColor blueColor] range:winRange];
    
    
    NSMutableAttributedString* lossString = [[NSMutableAttributedString alloc]initWithString:[NSString stringWithFormat:@"%d",losses]];
    NSRange lossesRange;
    lossesRange.length = lossString.length;
    lossesRange.location = 0;
    [lossString addAttribute:NSForegroundColorAttributeName value:[UIColor redColor] range:lossesRange];
    
    [attrString appendAttributedString:winString];
    [attrString appendAttributedString: [[NSAttributedString alloc]initWithString:@" - " ]];
    [attrString appendAttributedString:lossString];
    [attrString appendAttributedString: [[NSAttributedString alloc]initWithString:@" - " ]];
    
    NSString *tieString = [NSString stringWithFormat:@"%d",ties] ;
                           
    [attrString appendAttributedString: [[NSAttributedString alloc]initWithString:tieString]];
    
    return attrString;
}
@end
