//
//  ViewController.m
//  CustomSparklineColumn
//
//  Created by Darrell Kress on 2/24/14.
//  Copyright (c) 2014 Darrell Kress. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()
{
    IGGridView* _grid;
    // the datasource property on the iggridview holds a weak reference to this object, so we need
    // to make sure the view controller (or another persistant object) maintains the helper;
    IGGridViewDataSourceHelper* _helper;
}
@end

@implementation ViewController

-(NSArray*)makeData
{
    // making some data
    NSMutableArray* data = [[NSMutableArray alloc]init];
    for (int i = 0 ; i < 40 ; i++)
    {
        TeamSeasonData* t = [[TeamSeasonData alloc]init];
        t.teamName = [NSString stringWithFormat:@"Team %d",i ];
        NSMutableArray* gameData = [[NSMutableArray alloc]init];
        for (int j = 0 ; j < 10 ; j++)
        {
            int winOrLoss = rand() % 11;
            
            if ( winOrLoss == 0)
            {
                [ gameData addObject:[ NSNumber numberWithInt:0]]; // Tie
            }
            else if ( winOrLoss % 2 == 0 )
            {
                [ gameData addObject:[ NSNumber numberWithInt:1]];  // Win
            }
            else
            {
                [ gameData addObject:[ NSNumber numberWithInt:-1]];  // Loss
            }
        }
        t.recordData = gameData;
        [data addObject:t];
    }
    return data;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    
    // adding a grid to the view and setting up properties on it
    _grid = [[IGGridView alloc]initWithFrame:CGRectMake(0, 0, self.view.bounds.size.width, self.view.bounds.size.height)];
    _grid.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
    [self.view addSubview:_grid];
    _grid.rowHeight = 150.0;
    
    // setting up the DataSourceHelper
    _helper = [[IGGridViewDataSourceHelper alloc]init];
    _helper.autoGenerateColumns = NO;
    
    // Adding columns to our grid, including our custom columns
    IGGridViewColumnDefinition* nameColumn = [[IGGridViewColumnDefinition alloc]initWithKey:@"teamName"];
    [_helper.columnDefinitions addObject:nameColumn];
    nameColumn.headerText = @"Team Name";
    
    CurrentRecordColumnDefinition* currentRecColumn = [[CurrentRecordColumnDefinition alloc]initWithKey:@"currentRecord"];
    currentRecColumn.headerText = @"Overall Record";
    [_helper.columnDefinitions addObject:currentRecColumn];
    
    IGSparklineColumnDefinition* recordColumn = [[IGSparklineColumnDefinition alloc]initWithKey:@"recordData"];
    [_helper.columnDefinitions addObject:recordColumn];
    recordColumn.headerText = @"Current Streak";
    _helper.data = [self makeData];
    _grid.dataSource = _helper;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
